/**
 * <copyright>
 * </copyright>
 *
 * $Id: COBOLClassifier.java,v 1.2 2004/10/21 21:57:45 akkina Exp $
 */
package com.ibm.etools.cobol;

import com.ibm.etools.tdlang.TDLangClassifier;

import org.eclipse.emf.common.util.EList;

/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>Classifier</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * COBOLClassifier class is the parent class of COBOLComposedType and COBOLSimpleType and contains the 'typedef' attribute.  
 * 
 * The best way to think of the effect of TYPEDEFs in COBOL is as lexical substitution, similar to simple C macros.  Replace the TYPE clause by everything following the TYPEDEF keyword.  Then, after adjusting the level numbers appropriately, the result has to be legal COBOL (except for the adjusted level numbers themselves, which can exceed 49).  The actual rules are quite complicated, as you might expect, so rather than describe those, here are some examples:
 * 
 * A simple way of enforcing shop standards for financial data:
 * Definition:
 * 1 uniform-amount typedef usage comp pic s9(6)v99 synchronized.
 * Reference:
 * 1 account-record.
 *   ...
 *   5 prior-balance type uniform-amount.
 *   5 current-balance type to uniform-amount.
 *   ...
 * 
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link com.ibm.etools.cobol.COBOLClassifier#getTypedef <em>Typedef</em>}</li>
 *   <li>{@link com.ibm.etools.cobol.COBOLClassifier#getTypedElement <em>Typed Element</em>}</li>
 * </ul>
 * </p>
 *
 * @see com.ibm.etools.cobol.COBOLPackage#getCOBOLClassifier()
 * @model abstract="true"
 * @generated
 */
public interface COBOLClassifier extends TDLangClassifier {
	/**
	 * Returns the value of the '<em><b>Typedef</b></em>' attribute.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * <!-- begin-model-doc -->
	 * User-defined types are introduced by using the TYPEDEF attribute, and referred to by the TYPE clause.  If type is user-defined, 'typedef' = true.  
	 * 
	 * TypeDef = False for Redefine/UNION
	 * <!-- end-model-doc -->
	 * @return the value of the '<em>Typedef</em>' attribute.
	 * @see #setTypedef(Boolean)
	 * @see com.ibm.etools.cobol.COBOLPackage#getCOBOLClassifier_Typedef()
	 * @model 
	 * @generated
	 */
	Boolean getTypedef();

	/**
	 * Sets the value of the '{@link com.ibm.etools.cobol.COBOLClassifier#getTypedef <em>Typedef</em>}' attribute.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param value the new value of the '<em>Typedef</em>' attribute.
	 * @see #getTypedef()
	 * @generated
	 */
	void setTypedef(Boolean value);

	/**
	 * Returns the value of the '<em><b>Typed Element</b></em>' reference list.
	 * The list contents are of type {@link com.ibm.etools.cobol.COBOLElement}.
	 * It is bidirectional and its opposite is '{@link com.ibm.etools.cobol.COBOLElement#getSharedType <em>Shared Type</em>}'.
	 * <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of the '<em>Typed Element</em>' reference list isn't clear,
	 * there really should be more of a description here...
	 * </p>
	 * <!-- end-user-doc -->
	 * @return the value of the '<em>Typed Element</em>' reference list.
	 * @see com.ibm.etools.cobol.COBOLPackage#getCOBOLClassifier_TypedElement()
	 * @see com.ibm.etools.cobol.COBOLElement#getSharedType
	 * @model type="com.ibm.etools.cobol.COBOLElement" opposite="sharedType"
	 * @generated
	 */
	EList getTypedElement();

} // COBOLClassifier
